Re: [O] An Org centric research lab: Goodbye MS word, excel, and powerpoint

2014-07-11 Thread Martin Schöön
Python is widely used in industry and these days many CAD/CAE tools use
Python for scripting...

-- 
Martin Schöön

http://hem.bredband.net/b262106/index.html


Re: [O] emails written in Org Mode

2014-07-11 Thread Joseph Vidal-Rosset
Leven.11   juil.2014à02:39:42   ,GrantRettke
g...@wisdomandwonder.com a envoyé ce message:
 Hi Joseph,

 What directions did you follow for working with gmail?

 Kind regards,

 gcr

Hi Grant,

Gnus   +   gmail  is   pretty   well   documented.   Have  a   look   on
http://www.emacswiki.org/emacs/GnusGmail   .  My   setup  is   not  very
different, but I can send to you my .gnus.el if you want it. 

I  must say  that I  am  already convinced  that using  gnus alone  with
org-mode (i.e. with links) is  certainly more efficient, but it requires
more time to learn it. It is an holiday project. :)

Best wishes,

Jo. 



Re: [O] cache problem, with ECM

2014-07-11 Thread Alan Schmitt
On 2014-07-09 10:11, Alan Schmitt alan.schm...@polytechnique.org writes:

 Hello,

 I noticed this morning, after updating org-mode to the latest version,
 that I would get an error with a trace related to a cache even if a just
 started emacs. It took me a while to get down to an ECM, but here it is.

As a quick follow-up, I can get rid of the cache corruption by not using
the log book (I set '(setq org-log-into-drawer nil)'). If others are
seeing such cache corruption, this might be a temporary workaround.

Best,

Alan

-- 
OpenPGP Key ID : 040D0A3B4ED2E5C7


pgpylOtMjhrcw.pgp
Description: PGP signature


[O] [PATCH] org-git-link.el: Add support for line in org-git-link

2014-07-11 Thread Samuel Loury
Hi,

I would like to submit a small enhancement of the org-git-link package
to add the storing and use of a line third argument.

Please find the patch attached to this mail. I hope you'll find it
useful.

Thanks for your attention.
From 7144b05b9d024222cb7e46a370ba3d974ae235af Mon Sep 17 00:00:00 2001
From: Konubinix konubi...@gmail.com
Date: Fri, 11 Jul 2014 09:10:02 +0200
Subject: [PATCH] org-git-link.el: Add support for line in org-git-ling

* org-git-link.el (org-git-open): Jump to the line if provided in the link.
(org-git-split-string): Parse a third element of the list and change the error
message accordingly.
(org-git-create-git-link): Accept the third optional line argument.
(org-git-store-link): call `org-git-create-git-link' with the current line
number.
---
 contrib/lisp/org-git-link.el | 27 +--
 1 file changed, 17 insertions(+), 10 deletions(-)

diff --git a/contrib/lisp/org-git-link.el b/contrib/lisp/org-git-link.el
index 7d95bbb..ad0ce71 100644
--- a/contrib/lisp/org-git-link.el
+++ b/contrib/lisp/org-git-link.el
@@ -98,10 +98,12 @@
   (let* ((strlist (org-git-split-string str))
  (filepath (first strlist))
  (commit (second strlist))
+ (line (third strlist))
  (dirlist (org-git-find-gitdir (file-truename filepath)))
  (gitdir (first dirlist))
  (relpath (second dirlist)))
-(org-git-open-file-internal gitdir (concat commit : relpath
+(org-git-open-file-internal gitdir (concat commit : relpath))
+(when line (goto-line (string-to-int line)
 

 ;; Utility functions (file names etc)
@@ -141,16 +143,19 @@
 ;; splitting the link string
 
 ;; Both link open functions are called with a string of
 ;; consisting of two parts separated by a double colon (::).
 (defun org-git-split-string (str)
-  Given a string of the form \str1::str2\, return a list of
-  two substrings \'(\str1\ \str2\). If the double colon is mising, take str2 to be the empty string.
+  Given a string of the form \str1::str2::str3\, return a list of
+  three substrings \'(\str1\ \str2\ \str3\). If there are less
+than two double colons, str2 and/or str3 may be set the empty string.
   (let ((strlist (split-string str ::)))
 (cond ((= 1 (length strlist))
-   (list (car strlist) ))
+   (list (car strlist)  ))
   ((= 2 (length strlist))
+   (append strlist (list )))
+  ((= 3 (length strlist))
strlist)
-  (t (error org-git-split-string: only one :: allowed: %s str)
+  (t (error org-git-split-string: only one or two :: allowed: %s str)
 
 ;; finding the file name part of a commit
 (defun org-git-link-filename (str)
@@ -168,22 +173,24 @@
   (concat branch @{ timestring }))
 
 
-(defun org-git-create-git-link (file)
+(defun org-git-create-git-link (file optional line)
   Create git link part to file at specific time
   (interactive FFile: )
   (let* ((gitdir (first (org-git-find-gitdir (file-truename file
  (branchname (org-git-get-current-branch gitdir))
  (timestring (format-time-string %Y-%m-%d (current-time
-(concat git: file :: (org-git-create-searchstring branchname timestring
+(concat git: file :: (org-git-create-searchstring branchname timestring)
+	(if line (format ::%s line) 
 
 (defun org-git-store-link ()
   Store git link to current file.
   (when (buffer-file-name)
-(let ((file (abbreviate-file-name (buffer-file-name
+(let ((file (abbreviate-file-name (buffer-file-name)))
+	  (line (line-number-at-pos)))
   (when (org-git-gitrepos-p file)
 	(org-store-link-props
 	 :type git
-	 :link (org-git-create-git-link file))
+	 :link (org-git-create-git-link file line))
 
 (add-hook 'org-store-link-functions 'org-git-store-link)
 
@@ -141,16 +143,19 @@
 
 ;; Both link open functions are called with a string of
-;; consisting of two parts separated by a double colon (::).
+;; consisting of three parts separated by a double colon (::).
 (defun org-git-split-string (str)
-- 
2.0.0.rc2

-- 
Konubinix
GPG Key: 7439106A
Fingerprint: 5993 BE7A DA65 E2D9 06CE  5C36 75D2 3CED 7439 106A


pgpRw1PqBxmZs.pgp
Description: PGP signature


Re: [O] An Org centric research lab: Goodbye MS word, excel, and powerpoint

2014-07-11 Thread Detlef Steuer
Am Wed, 9 Jul 2014 22:37:12 +
schrieb Doyley, Marvin M. mdoy...@ur.rochester.edu:

  I notice that you prefer to use python rather than matlab. Is there
 a reason  for this ? Matlab is free at my institution so cost  is not
 an issue.

Free here, too. 

But we prefer R for Data Analysis, not at least because it is OS agnostic.

Furthermore, when I was a student myself, I *hated* to be forced into 
the overcrowded, overheated lab for programming. Now everybody can choose to 
programm at home, in the lab, on the train or on the beach. (Ok, the last one 
is not too important most of the time over here, but today it would be an 
alternative.)

Have a nice summer

Detlef




Re: [O] Mathjax vs. problems with imagemagick

2014-07-11 Thread Joseph Vidal-Rosset
Le  ven. 11  juil. 2014  à 02:59:23  , Nick  Dokos ndo...@gmail.com  a
envoyé ce message:


 Can you please post an example org file and the tex file that's produced
 that gives you such bad images?

Dear Nick,

I sent an email three days ago to tell you that I've got the solution. I
said: 

 I have put again in my init.el the code from the page 
[[http://orgmode.org/worg/org-tutorials/org-latex-preview.html]] , i.e.

(setq org-latex-listings 'minted) (require 'ox-latex) (add-to-list 
'org-latex-packages-alist '( minted))


and I have added :

;; Let the exporter use the -shell-escape option to let latex
;; execute external programs.
;; This obviously and can be dangerous to activate!
(setq org-latex-pdf-process
  '(xelatex -shell-escape -interaction nonstopmode -output-directory %o 
%f))


Now it works. But I do not know really why. End of quotation .

I would have been happy to show you an example. But now I meet again, as
often, the tiring same problem: 

Creating LaTeX Image...
Failed to create dvi file from /tmp/orgtex15065yFA.tex
Creating LaTeX Image...
Failed to create dvi file from /tmp/orgtex15065MaM.tex
Ispell process killed
Starting new Ispell process [aspell::en] ...
Mark set
Sending...
Mark set [2 times]
mm-insert-file-contents: Opening input file: aucun fichier ou dossier de ce 
type, /tmp/ltxpng/latex15065_PG_37f10648c57a40194a74eaabbaa5c1678a5d2046.png
Mark set

Nevertheless,  the png  file is  in  /tmp/ltxpng and  it is  a nice  png
image. 

I  remind  that the  error  in  creating the  dvi  file  was created  by
minted. I  deleted every reference  to minted and  it worked, but  now I
realize that  without minted the  use of bussproofs.sty cannot  work for
html conversion. :S 

I guess that I have to put in  my .bashrc a command to say that I always
want to use latex with -shell-escape option  , but I am not sure that it
is the best solution. 

Every help is welcome. 

Best regards,

Jo. 




Re: [O] SOLVED: source code block language 'makefile' and listings package

2014-07-11 Thread Rainer M Krug


Envoyé de mon iPhone

 Le 8 juil. 2014 à 14:40, Nick Dokos ndo...@gmail.com a écrit :
 
 Rainer M Krug rai...@krugs.de writes:
 
 Much simpler then that: I simply changed the variable
 org-latex-listings-langs to include makefile:
 
 ,
 | (setq org-latex-listings-langs 
 |   '((emacs-lisp Lisp) 
 | (lisp Lisp)
 ... 
 | (sql SQL)
 | (sqlite sql)
 | (makefile make)))
 `
 
 Works perfectly.
 
 Now if I just could figure out on how I can simply *add* the makefile to
 the list without defining it completely new..
 
 Two methods:
 
 this one is pretty much generic lisp:
 
 --8---cut here---start-8---
 (setq org-latex-listings-langs
  (append org-latex-listings-langs '((makefile make
 --8---cut here---end---8---
 
 A slightly simpler, more idiomatic emacs-lisp way:
 
 --8---cut here---start-8---
 (add-to-list 'org-latex-listings-langs '(makefile make))
 --8---cut here---end---8---
 

Thanks - learned something more. 

Cheers,

Rainer 

 -- 
 Nick
 
 


Re: [O] emails written in Org Mode

2014-07-11 Thread Alan Schmitt
Hello Thorsten,

On 2014-07-10 15:27, Thorsten Jolitz tjol...@gmail.com writes:

 Looks like the hooks are not set. Here (again) my configuration from
 init.el: 

 ,
 | (add-hook 'emacs-lisp-mode-hook 'outline-minor-mode)
 | (add-hook 'message-mode-hook 'outline-minor-mode)
 | ;; more hooks for other major-modes ...
 |
 | ;; outorg ; = required indirectly
 | ;; (require 'outorg)
 | 
 | ;; outshine
 | (require 'outshine)
 | (add-hook 'outline-minor-mode-hook
 |   'outshine-hook-function) ; = important!
 | 
 | (setq outshine-use-speed-commands t)
 | 
 | ;; navi-mode   ; = optional
 | (require 'navi-mode)
 | 
 | ;; poporg  ; = optional
 | (require 'poporg)
 `

Adding these lines worked. I think I was missing both the outline mode
and the outshine hook.

 - does outorg require outshine to work? If so, it may be good to mark
 the latter as a dependency of the former.

 Yes. 
 With mark the latter as a dependency of the former you mean in the
 MELPA package description?

Yes, or adding an explicit dependency in MELPA such that if one
installs outorg, then outshine is automatically installed.

 - there is no installation instructions on the package description on
 MELPA. Where can I find the installation description referred to
 above?

 ,
 | https://github.com/tj64/outshine
 | https://github.com/tj64/outorg
 | https://github.com/tj64/navi
 `

 or  

 ,
 | http://orgmode.org/worg/org-tutorials/org-outside-org.html
 `

Adding these to the MELPA description would be quite useful.

Thanks again,

Alan

-- 
OpenPGP Key ID : 040D0A3B4ED2E5C7


pgpKvfzx1eYTj.pgp
Description: PGP signature


Re: [O] cache problem, with ECM

2014-07-11 Thread Daniel Clemente
 
 As a quick follow-up, I can get rid of the cache corruption by not using
 the log book (I set '(setq org-log-into-drawer nil)'). If others are
 seeing such cache corruption, this might be a temporary workaround.
 
  I also am seeing many cache problems, e.g.
  - after changing TODO→DONE a repeating task with .+1m , it stays DONE (not 
TODO), the date doesn't change to next month, and C-e stops working (Wrong type 
argument: number-or-marker-p, nil). The backtrace included some function like 
…-update-cache-…
  - lines that should appear inside log drawer (like :LAST_REPEAT:) appear 
anywhere, e.g. in between the CLOCK: […]--[…] entries




Re: [O] cache problem, with ECM

2014-07-11 Thread Alan Schmitt
On 2014-07-11 11:34, Daniel Clemente n142...@gmail.com writes:

 
 As a quick follow-up, I can get rid of the cache corruption by not using
 the log book (I set '(setq org-log-into-drawer nil)'). If others are
 seeing such cache corruption, this might be a temporary workaround.
 
   I also am seeing many cache problems, e.g.
   - after changing TODO→DONE a repeating task with .+1m , it stays DONE (not 
 TODO), the date doesn't change to next month, and C-e stops working (Wrong 
 type argument: number-or-marker-p, nil). The backtrace included some function 
 like …-update-cache-…
   - lines that should appear inside log drawer (like :LAST_REPEAT:) appear 
 anywhere, e.g. in between the CLOCK: […]--[…] entries

This is very similar to what I witness (the error is the same in my
case, and the problem happens with a LOGBOOK created but no data put
inside). What's worse: after the problem has happened once, I cannot
unfold a task without getting an exception, and I have to restart emacs.

Alan

-- 
OpenPGP Key ID : 040D0A3B4ED2E5C7


pgpv4oZHXgLc3.pgp
Description: PGP signature


[O] How to filter agenda for Word1 OR Word2?

2014-07-11 Thread Martin Beck
I have a search result (created by a search agenda C-C a s) and I want to narrow it down further with additional criteria.

I tried to use the = key for Narrow to entries matching regexp, but I did not find out how to combine several terms in here.



As long as I only enter one word, it works. But if I want to filter for criteria like



Word1 OR Word2

or (Word1 OR Word2) AND Word3

or (Word1 OR Word2) AND NOT (Word3 OR Word4)



I get no results just by entering

e.g. Word1Word2

or Word1Word2



Im sure this is trivial, but Im not an expert in regular expressions and currently dont see how to solve that.

:-(



Thanks a lot and kind regards



Martin



[O] lists with a , b, c, or i, ii, iii ...

2014-07-11 Thread Joseph Vidal-Rosset
Hello everybody,

I'm trying to get  orderd lists in org-mode with other values than 1. 2. ...

I do not succeed to get lists like:

i.  blablabla ...
ii. blablabla
iii. blabla..

or

a.  sentence
b.  another sentence..

Could you help me please?

Best wishes,

Jo.


Re: [O] Issue with multiple references to the same footnote in LaTeX export

2014-07-11 Thread York Zhao
Any one?


On Wed, Jul 9, 2014 at 2:07 PM, York Zhao gtdplatf...@gmail.com wrote:

 If I have multiple references to the same footnote, in LaTeX export only
 the
 first reference is a clickable link, the rest are exported as dead number
 referring to the footnote definition, but not clickable links. I have
 `org-footnote-section' set to `nil' by the way.

 Here's ECM:

 --8---cut here---start-8---
 #+LaTeX_CLASS: article

 * Multiple reference to the same footnote 1
 This is footnote reference [fn:1]. This is another reference to the same
 footnote [fn:1]

 [fn:1] Footnote definition.

 * Multiple reference to the same footnote 2
 This is footnote reference [fn:myfootnote]. This is another reference to
 the
 same footnote [fn:myfootnote]

 [fn:myfootnote] Footnote definition.

 * Multiple reference to the same footnote 3
 This is footnote reference [fn:myfootnote3: Footnote definition.]. This is
 another reference to the same footnote [fn:myfootnote3]

 * Local Variables
 # Local Variables:
 # eval: (add-to-list (make-local-variable
 'org-latex-default-packages-alist) '( setspace nil))
 # End:
 --8---cut here---end---8---

 Regards,

 York




Re: [O] lists with a , b, c, or i, ii, iii ...

2014-07-11 Thread Nick Dokos
Joseph Vidal-Rosset joseph.vidal.ros...@gmail.com writes:


 I'm trying to get  orderd lists in org-mode with other values than
 1. 2. ...

 I do not succeed to get lists like:

 i.  blablabla ...
 ii. blablabla
 iii. blabla..


Not possible in org AFAIK. It might be possible
to get them in the exported PDF file by
playing LaTeX games, but I'm not sure.

 or

 a.  sentence
 b.  another sentence..

 Could you help me please?


C-h v org-alphabetical-lists RET

-- 
Nick




Re: [O] lists with a , b, c, or i, ii, iii ...

2014-07-11 Thread Nick Dokos
Nick Dokos ndo...@gmail.com writes:

 Joseph Vidal-Rosset joseph.vidal.ros...@gmail.com writes:


 I'm trying to get  orderd lists in org-mode with other values than
 1. 2. ...

 I do not succeed to get lists like:

 i.  blablabla ...
 ii. blablabla
 iii. blabla..


 Not possible in org AFAIK. It might be possible
 to get them in the exported PDF file by
 playing LaTeX games, but I'm not sure.

 or

 a.  sentence
 b.  another sentence..

 Could you help me please?


 C-h v org-alphabetical-lists RET

Sorry, that variable is obsolete (although it should still work for
now).  I should have pointed you to the modern version instead:

org-list-allow-alphabetical


Note the caveat in the doc:

,
| This variable needs to be set before org.el is loaded.  If you
| need to make a change while Emacs is running, use the customize
| interface or run the following code after updating it:
| 
|   (when (featurep 'org-element) (load org-element t t))
`

I tried it and it works:

  a. foo - press M-RET
  b. bar

-- 
Nick




Re: [O] lists with a , b, c, or i, ii, iii ...

2014-07-11 Thread Joseph Vidal-Rosset
2014-07-11 16:17 GMT+02:00 Nick Dokos ndo...@gmail.com:

 orry, that variable is obsolete (although it should still work for
 now).  I should have pointed you to the modern version instead:

 org-list-allow-alphabetical


 Note the caveat in the doc:

 ,
 | This variable needs to be set before org.el is loaded.  If you
 | need to make a change while Emacs is running, use the customize
 | interface or run the following code after updating it:
 |
 |   (when (featurep 'org-element) (load org-element t t))
 `

 I tried it and it works:

   a. foo - press M-RET
   b. bar



Do not apologize, I have noticed that the variable was obsolete and I have
tried to customize the new variable. I have even written the code
(when (featurep 'org-element) (load org-element t t))  in my init.el
(which is too big and really a mess), and it doe not work either...

Do not waste more time than me on this small problem which certainly comes
from my init.el...

Best regards,

Jo.


Re: [O] Mathjax vs. problems with imagemagick

2014-07-11 Thread Nick Dokos
Joseph Vidal-Rosset joseph.vidal.ros...@gmail.com writes:

 Le  ven. 11  juil. 2014  à 02:59:23  , Nick  Dokos ndo...@gmail.com  a
 envoyé ce message:


 Can you please post an example org file and the tex file that's produced
 that gives you such bad images?

 Dear Nick,

 I sent an email three days ago to tell you that I've got the solution. I
 said: 


Yes, I remember this, but what with the mail delays and time reordering of
the replies, I got confused.


 mm-insert-file-contents: Opening input file: aucun fichier ou dossier
 de ce type,
 /tmp/ltxpng/latex15065_PG_37f10648c57a40194a74eaabbaa5c1678a5d2046.png
 Mark set

 Nevertheless,  the png  file is  in  /tmp/ltxpng and  it is  a nice  png
 image. 


And you are sure that it is named
latex15065_PG_37f10648c57a40194a74eaabbaa5c1678a5d2046.png ?
The existing file might be a remnant from a previous run with a slightly
different name (uuid readability is not the best :-) )

 I  remind  that the  error  in  creating the  dvi  file  was created  by
 minted. I  deleted every reference  to minted and  it worked, but  now I
 realize that  without minted the  use of bussproofs.sty cannot  work for
 html conversion. :S 

 I guess that I have to put in  my .bashrc a command to say that I always
 want to use latex with -shell-escape option  , but I am not sure that it
 is the best solution. 


-shell-escape is a security risk, allowing arbitrary programs to
execute, but if you are careful about what you allow and don't get
careless, I think it's reasonable to set it once and for all. I do that
because I use minted all the time (it's also needed by some svg package
that I occasionally use). But I do try to be careful about what new
latex packages I install.

Nick




Re: [O] lists with a , b, c, or i, ii, iii ...

2014-07-11 Thread Nick Dokos
Joseph Vidal-Rosset joseph.vidal.ros...@gmail.com writes:

 Do not apologize, I have noticed that the variable was obsolete and I have 
 tried to customize the new variable. I have even
 written the code
 (when (featurep 'org-element) (load org-element t t))  in my init.el  
 (which is too big and really a mess), and it doe not work
 either...


I went the customize route.

Nick




Re: [O] Mathjax vs. problems with imagemagick

2014-07-11 Thread Joseph Vidal-Rosset
2014-07-11 17:59 GMT+02:00 Nick Dokos ndo...@gmail.com:

 And you are sure that it is named
 latex15065_PG_37f10648c57a40194a74eaabbaa5c1678a5d2046.png ?
 The existing file might be a remnant from a previous run with a slightly
 different name (uuid readability is not the best :-) )


:)  I am pretty sure, yes ! :)


   I  remind  that the  error  in  creating the  dvi  file  was created  by
  minted. I  deleted every reference  to minted and  it worked, but  now I
  realize that  without minted the  use of bussproofs.sty cannot  work for
  html conversion. :S
 
  I guess that I have to put in  my .bashrc a command to say that I always
  want to use latex with -shell-escape option  , but I am not sure that it
  is the best solution.
 

 -shell-escape is a security risk, allowing arbitrary programs to
 execute, but if you are careful about what you allow and don't get
 careless, I think it's reasonable to set it once and for all. I do that
 because I use minted all the time (it's also needed by some svg package
 that I occasionally use). But I do try to be careful about what new
 latex packages I install.


I have just to find how to write this setup in my .bashrc file. If you know
the command line for a Linux user, do not hesitate to tell me. It will be
more quick for me !

Best wishes and thanks again !

Jo.


Re: [O] Mathjax vs. problems with imagemagick

2014-07-11 Thread Nick Dokos
Joseph Vidal-Rosset joseph.vidal.ros...@gmail.com writes:

  I guess that I have to put in  my .bashrc a command to say that I always
  want to use latex with -shell-escape option  , but I am not sure that it
  is the best solution.
 

 -shell-escape is a security risk, allowing arbitrary programs to
 execute, but if you are careful about what you allow and don't get
 careless, I think it's reasonable to set it once and for all. I do that
 because I use minted all the time (it's also needed by some svg package
 that I occasionally use). But I do try to be careful about what new
 latex packages I install.

 I have just to find how to write this setup in my .bashrc file. If you know 
 the command line for a Linux user, do not hesitate to
 tell me. It will be more quick for me !


Sorry, I misspoke: I only set it in org. Most of my latex usage is
org-latex-pdf nowadays, so I don't bother to do it from the shell. On
the rare occasions when I do it from the command line, I type the option
explicitly if needed.

My org-latex-pdf-process setting is

  (setq org-latex-pdf-process '(texi2dvi --shell-escape --pdf %f))

and I'm experimenting with

  (setq org-latex-pdf-process '(latexmk --shell-escape -pdf -xelatex %f))

HTH,
Nick







Re: [O] Mathjax vs. problems with imagemagick

2014-07-11 Thread Joseph Vidal-Rosset
2014-07-11 20:05 GMT+02:00 Nick Dokos ndo...@gmail.com:

 My org-latex-pdf-process setting is

   (setq org-latex-pdf-process '(texi2dvi --shell-escape --pdf %f))

 and I'm experimenting with

   (setq org-latex-pdf-process '(latexmk --shell-escape -pdf -xelatex %f))



I am going to test this code, and I will be back to tell you how it works
for me.

Many many thanks.

Best wishes

Jo.


Re: [O] How to filter agenda for Word1 OR Word2?

2014-07-11 Thread Alexander Baier
On 2014-07-11 13:26 Martin Beck wrote:
 I have a search result (created by a search agenda C-C a s) and I
 want to narrow it down further with additional criteria.
 I tried to use the = key for Narrow to entries matching regexp,
 but I did not find out how to combine several terms in here.
  
 As long as I only enter one word, it works. But if I want to filter
 for criteria like
  
 Word1 OR Word2
 or (Word1 OR Word2) AND Word3
 or (Word1 OR Word2) AND NOT (Word3 OR Word4)
  
 I get no results just by entering
 e.g. Word1|Word2
 or Word1Word2
  
 I'm sure this is trivial, but I'm not an expert in regular
 expressions and currently don't see how to solve that.
 :-(

Using \(Word1\)\|\(Word2\) works for me. If you find it troublesome to
type a lot of these escaped parens, you might want to try
smartparens-mode for auto insertion of the closing _escaped_ paren.

As an example, if you type \(, smartparens will automatically insert
\) after point. You can even navigate over these groups via sexps
commands.

HTH,
-- 
Alexander Baier



[O] How to call org-display-inline-images so that after a graphviz block is evaluated the image is refreshed?

2014-07-11 Thread Grant Rettke
Hi,

The ability to use graphviz in an org document is stellar and makes it
so much more productive to use org.

Combined with inline image display, it is a powerhouse combo.

After evaluating my source block, I would like to refresh the generated image.

Thus far, I just call org-display-inline-image.

What is the best way to automate it so that the images are always up to date?

Kind regards,

Grant Rettke | ACM, ASA, FSF, IEEE, SIAM
g...@wisdomandwonder.com | http://www.wisdomandwonder.com/
“Wisdom begins in wonder.” --Socrates
((λ (x) (x x)) (λ (x) (x x)))
“Life has become immeasurably better since I have been forced to stop
taking it seriously.” --Thompson



Re: [O] How to call org-display-inline-images so that after a graphviz block is evaluated the image is refreshed?

2014-07-11 Thread Ken Mankoff

Try (org-redisplay-inline-images). Note re.

#+BEGIN_SRC lang :post (org-redisplay-inline-images)
#+END_SRC
#+RESULTS:

  -k.

* On 2014-07-11 at 20:14, Grant Rettke wrote:
 Hi,

 The ability to use graphviz in an org document is stellar and makes it
 so much more productive to use org.

 Combined with inline image display, it is a powerhouse combo.

 After evaluating my source block, I would like to refresh the generated image.

 Thus far, I just call org-display-inline-image.

 What is the best way to automate it so that the images are always up to date?

 Kind regards,

 Grant Rettke | ACM, ASA, FSF, IEEE, SIAM
 g...@wisdomandwonder.com | http://www.wisdomandwonder.com/
 “Wisdom begins in wonder.” --Socrates
 ((λ (x) (x x)) (λ (x) (x x)))
 “Life has become immeasurably better since I have been forced to stop
 taking it seriously.” --Thompson




Re: [O] An Org centric research lab: Goodbye MS word, excel, and powerpoint

2014-07-11 Thread Ken Mankoff
Hi Marvin,

* On 2014-07-09 at 18:37, Doyley, Marvin M. wrote:
 I notice that you prefer to use python rather than matlab. Is there a
 reason for this ? Matlab is free at my institution so cost is not an
 issue.

An additional blog post (with good discussion and links to other posts)
on the Python v. MATLAB debate:

http://lorenabarba.com/blog/why-i-push-for-python/

and

http://phillipmfeldman.org/Python/Advantages_of_Python_Over_Matlab.html

  -k.



Re: [O] An Org centric research lab: Goodbye MS word, excel, and powerpoint

2014-07-11 Thread Grant Rettke
Octave is an option, too: https://www.gnu.org/software/octave/
Grant Rettke | ACM, ASA, FSF, IEEE, SIAM
g...@wisdomandwonder.com | http://www.wisdomandwonder.com/
“Wisdom begins in wonder.” --Socrates
((λ (x) (x x)) (λ (x) (x x)))
“Life has become immeasurably better since I have been forced to stop
taking it seriously.” --Thompson


On Fri, Jul 11, 2014 at 7:31 PM, Ken Mankoff mank...@gmail.com wrote:
 Hi Marvin,

 * On 2014-07-09 at 18:37, Doyley, Marvin M. wrote:
 I notice that you prefer to use python rather than matlab. Is there a
 reason for this ? Matlab is free at my institution so cost is not an
 issue.

 An additional blog post (with good discussion and links to other posts)
 on the Python v. MATLAB debate:

 http://lorenabarba.com/blog/why-i-push-for-python/

 and

 http://phillipmfeldman.org/Python/Advantages_of_Python_Over_Matlab.html

   -k.




Re: [O] An Org centric research lab: Goodbye MS word, excel, and powerpoint

2014-07-11 Thread Grant Rettke
Now that I wrote that... MATLAB is totally worth the money.

A nice option for reproducible research is also to develop on MATLAB
and just make sure that OCTAVE can run it, too. Nice when you don't
want to worry about N licenses for deploying on a HPC cluster.
Grant Rettke | ACM, ASA, FSF, IEEE, SIAM
g...@wisdomandwonder.com | http://www.wisdomandwonder.com/
“Wisdom begins in wonder.” --Socrates
((λ (x) (x x)) (λ (x) (x x)))
“Life has become immeasurably better since I have been forced to stop
taking it seriously.” --Thompson


On Fri, Jul 11, 2014 at 9:03 PM, Grant Rettke g...@wisdomandwonder.com wrote:
 Octave is an option, too: https://www.gnu.org/software/octave/
 Grant Rettke | ACM, ASA, FSF, IEEE, SIAM
 g...@wisdomandwonder.com | http://www.wisdomandwonder.com/
 “Wisdom begins in wonder.” --Socrates
 ((λ (x) (x x)) (λ (x) (x x)))
 “Life has become immeasurably better since I have been forced to stop
 taking it seriously.” --Thompson


 On Fri, Jul 11, 2014 at 7:31 PM, Ken Mankoff mank...@gmail.com wrote:
 Hi Marvin,

 * On 2014-07-09 at 18:37, Doyley, Marvin M. wrote:
 I notice that you prefer to use python rather than matlab. Is there a
 reason for this ? Matlab is free at my institution so cost is not an
 issue.

 An additional blog post (with good discussion and links to other posts)
 on the Python v. MATLAB debate:

 http://lorenabarba.com/blog/why-i-push-for-python/

 and

 http://phillipmfeldman.org/Python/Advantages_of_Python_Over_Matlab.html

   -k.